#!/bin/sh

# tenter de récupérer l'utilisateur tomcat en analysant la ligne
# de commande de catalina
tomcat_user_par_catalina() {
   tomuser=$(ps aux|grep tomcat|grep catalina|sed 1q|gawk -F " " '{
      for (i=0;i<NF;i++) {
	 if ($i == "-user") {
	    j = i+1
	    {print $j}
	 }

      }}')
   echo $tomuser
}

# tenter de récupérer l'utilisateur tomcat par /etc/passwd
tomcat_user_par_passwd() {
   tomuser=$(gawk -F ":" '/tomcat/ {print $1}' /etc/passwd)
   echo $tomuser
}

# tenter de trouver l'utilisateur tomcat par les droits sur
# le dossier webapps
# parametre $1 : dossier webapps
tomcat_user_par_webapps_dir() {
   catalina_home=$(dirname "$1")
   tomuser=$(ls -l $catalina_home | gawk -F " " '/webapps/ {print $3}')
   echo $tomuser
}

# aide de l'application
aide() {
   echo "syntaxe : "$(basename $0) [option]
   echo "options"
   echo "-h --help	affiche cette aide"
   echo "-g --gui	lance l'installeur en mode graphique"
}

# Lancement de l'installeur ligne de commande par défaut
classe="Installeur"
while getopts ":hg-:" option
do
   if [ "$option" =	"-" ]
   then
      case $OPTARG in
         help)
            option="h"
            ;;
         gui)
            option="g"
            ;;
      esac
   fi
   
   case $option in
      h)
         aide
         exit 0
         ;;
      g)
         classe="IhmInstalleur"
         ;;
      ?)
         echo "option "$OPTARG" inconnue"
         exit 0
         ;;
   esac
done

if [ -z $(which gawk) ]
then
   echo "gawk introuvable, veuillez l'installer d'abord"
   exit 1
fi

if [ -z $(which sed) ]
then
   echo "sed est introuvable, veuillez l'installer d'abord"
   exit 1
fi

catalina=$(ps aux|grep tomcat|grep catalina)
if [ -z "$catalina" ]
then
   echo "Veuillez démarrer votre service tomcat"
   exit 1
fi

java=$(which java)
#java="/usr/local/java/jdk1.6.0_12/bin/java"

if [ -z "$java" ]
then
   echo "Pas de java trouvé : veuillez installer java"
   exit 1
fi

if [ $(id -u) -ne 0 ]
then
   echo "Vous devez être root pour exécuter l'installeur"
   exit 1
fi

ok_java=""

while [ -z "$ok_java" ]
do
   read -p "Utiliser "$java" [o/n] ? " ok_java
   if [ -z "$ok_java" ]
   then
      echo "Vous n'avez pas répondu à la question précédente !"
   elif [ "$ok_java" != "o" -a "$ok_java" != "oui " -a "$ok_java" != "n" -a "$ok_java" != "non" ]
   then
      ok_java=""
      echo "Réponse invalide, choisissez o (oui) ou n (non)"
   elif [ "$ok_java" = "n" -o "$ok_java" = "non" ]
   then
      java=""
      while [ -z "$java" ]
      do
	 read -p "Localisation de votre java ? " java
	 if [ -z "$ok_java" ]
	 then
	    echo "Vous n'avez pas répondu à la question précédente !"
	 elif [ ! -f "$java" -o ! -x "$java" ]
	 then
	    echo $java" : n'est pas un exécutable !"
	    java=""
	 fi
      done
   fi
done

echo "java : "$java


# chercher le dossier webapps des servlets à partir de la commande
# qui lance catalina
webapps_dir=$(ps aux|grep tomcat|grep catalina|sed 1q|gawk -F " " '{
    for (i=0;i<NF;i++) {
    	if (substr($i,0,15) == "-Dcatalina.base") {
        	{print substr($i, 17)}
     	}
   }}')/webapps

tomcat_user=$(tomcat_user_par_catalina)
if [ -z $tomcat_user ]
then
   tomcat_user=$(tomcat_user_par_passwd)
   if [ -z $tomcat_user ]
   then
      tomcat_user=$(tomcat_user_par_webapps_dir $webapps_dir)
   fi
fi

# Si pas trouvé, alors on prend root
tomcat_user=${tomcat_user:=root}
echo "tomcat user : "$tomcat_user
echo "webapps dir : "$webapps_dir

# fait la liste des dossiers existant dans webapps avant l'installation
liste_servlet_pre_install=$(ls $webapps_dir)

cp=".:lib/installeur.jar:lib/ant.jar:lib/ant-launcher.jar:lib/ant-nodeps.jar:lib/mysql-connector-java-5.0.6-bin.jar:lib/wizard.jar"
	
$java -classpath $cp $classe

if [ $? -ne 0 ]
then
   echo Erreur installation......arrêt !
   exit
fi


if [ -d $webapps_dir ]
then
   # fait la liste des dossiers existant dans webapps apres l'installation
   liste_servlet_post_install=$(ls $webapps_dir)

   # le groupe tomcat est root si il n'est pas trouvé
   tomcat_group=$(grep -E "^$tomcat_user" /etc/group | gawk -F ":" '{print $1}')
   tomcat_group=${tomcat_group:=root}
   echo "tomcat group : "$tomcat_group

   servlet=""
   if [ "$webapps_dir" != "/webapps" ]
   then
      # on va chercher le servlet créé
      for post in $liste_servlet_post_install
      do
	 existait_avant=0
	 for pre in $liste_servlet_pre_install
	 do
	    if [ "$post" = "$pre" ]
	    then
	       existait_avant=1
	       break
	    fi
	 done
	 if [ $existait_avant -eq 0 ]
	 then
	    servlet=$post
	    break
	 fi
      done
      chown -R $tomcat_user:$tomcat_group $webapps_dir/$servlet
   fi
fi

/bin/echo "Installation terminée. Veuillez redémarrer Tomcat pour intégrer OSAMES"